@@ -452,7 +452,7 @@ class FlowTCPFlag(IOperationByteShort, BinaryString, IPv4, IPv6):
     NAME = 'tcp-flags'
     FLAG = True
     converter = staticmethod(converter(TCPFlag.named))
-    decoder = staticmethod(decoder(ord, TCPFlag))
+    decoder = staticmethod(decoder(_number, TCPFlag))
 
 
 class FlowPacketLength(IOperationByteShort, NumericString, IPv4, IPv6):
@@ -479,7 +479,7 @@ class FlowTrafficClass(IOperationByte, NumericString, IPv6):
 
 
 # BinaryOperator
-class FlowFragment(IOperationByteShort, BinaryString, IPv4):
+class FlowFragment(IOperationByteShort, BinaryString, IPv4, IPv6):
     ID = 0x0C
     NAME = 'fragment'
     FLAG = True
